package main

import (
	"sort"

	"github.com/heroku/docker-registry-client/registry"
	"github.com/sirupsen/logrus"

	dt "gitlab.bertha.cloud/partitio/lab/dockertag"
)

func main() {
	url := "https://registry-1.docker.io/"
	hub, err := registry.New(url, "", "")
	if err != nil {
		logrus.Fatal(err)
	}
	tags, err := hub.Tags("library/nextcloud")
	if err != nil {
		logrus.Fatal(err)
	}
	var versions dt.Versions

	dt.MakeTags(tags...).Filter(func(t dt.Tag) bool {
		if !t.HasSuffix() {
			return false
		}
		v := t.Version()
		if !v.IsSemver() {
			return false
		}
		if !t.IsBeta() && !t.IsRC() && !versions.Contains(v) {
			versions = append(versions, v)
		}
		if !t.IsBeta() && !t.IsRC() && t.Contains("fpm") && t.Contains("alpine") && !t.Contains("RC") {
			logrus.Infof("version: %s tag: %s", v, t.Suffix())
			return true
		}
		return false
	})
	sort.Sort(versions)
	logrus.Info(versions)
}
